@@ -6,12 +6,12 @@
     <message>
         <location filename="bandpassdialog.ui" line="42"/>
         <source>Curve gain (dB)</source>
-        <translation>Gain (dB)</translation>
+        <translation>Gain de la courbe(dB)</translation>
     </message>
     <message>
         <location filename="bandpassdialog.ui" line="59"/>
         <source>Curve ripple (0.7 = 0dB)</source>
-        <translation>Oscillation (0.7 = 0dB)</translation>
+        <translation>Oscillation de la courbe(0.7 = 0dB)</translation>
     </message>
 </context>
 <context>
@@ -60,8 +60,8 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="120"/>
-        <location filename="mainwindow.ui" line="482"/>
-        <location filename="mainwindow.ui" line="792"/>
+        <location filename="mainwindow.ui" line="502"/>
+        <location filename="mainwindow.ui" line="822"/>
         <source>Hz</source>
         <translation>Hz</translation>
     </message>
@@ -77,455 +77,533 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="193"/>
-        <location filename="mainwindow.ui" line="358"/>
-        <location filename="mainwindow.ui" line="445"/>
-        <location filename="mainwindow.ui" line="698"/>
-        <location filename="mainwindow.ui" line="755"/>
+        <location filename="mainwindow.ui" line="378"/>
+        <location filename="mainwindow.ui" line="465"/>
+        <location filename="mainwindow.ui" line="728"/>
+        <location filename="mainwindow.ui" line="785"/>
         <source>L</source>
         <translation>L</translation>
     </message>
-    <message>
-        <location filename="mainwindow.ui" line="219"/>
-        <source>Sd</source>
-        <translation>Sd</translation>
-    </message>
     <message>
         <location filename="mainwindow.ui" line="233"/>
-        <source>m²</source>
-        <translation>m²</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="259"/>
-        <source>Re</source>
-        <translation>Re</translation>
+        <source>m</source>
+        <translation>m</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="273"/>
         <source>Ohm</source>
         <translation>Ohm</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="299"/>
+        <source>Vc</source>
+        <translation>Vc</translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="306"/>
+        <source>1</source>
+        <translation>1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="326"/>
         <source>Sealed enclosure</source>
         <translation>Enceinte close</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="309"/>
+        <location filename="mainwindow.ui" line="329"/>
         <source>1st order filter</source>
         <translation>filtre du premier ordre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="312"/>
+        <location filename="mainwindow.ui" line="332"/>
         <source>Simple, safe enclosure good for several speakers.</source>
         <translation>Enceinte simple et sûre, bonne pour certains haut-parleurs.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="341"/>
+        <location filename="mainwindow.ui" line="361"/>
         <source>Enclosure volume</source>
         <translation>Volume de l&apos;enceinte</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="396"/>
+        <location filename="mainwindow.ui" line="416"/>
         <source>Ported enclosure</source>
         <translation>Enceinte à évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="399"/>
+        <location filename="mainwindow.ui" line="419"/>
         <source>2nd order filter</source>
         <translation>filtre du second ordre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="402"/>
+        <location filename="mainwindow.ui" line="422"/>
         <source>Popular enclosure type to enhance bass for most speakers.</source>
         <translation>Type d&apos;enceinte réputé pour améliorer la réponse en basses pour la plupart des haut-parleurs.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="428"/>
+        <location filename="mainwindow.ui" line="448"/>
         <source>Enclosure volume (Vb)</source>
         <translation>Volume de l&apos;enceinte (Vb)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="465"/>
+        <location filename="mainwindow.ui" line="485"/>
         <source>Enclosure filter resonance (Fb)</source>
         <translation>Résonnance de l&apos;enceinte (Fb)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="516"/>
-        <location filename="mainwindow.ui" line="826"/>
+        <location filename="mainwindow.ui" line="536"/>
+        <location filename="mainwindow.ui" line="856"/>
         <source>Number of ports</source>
         <translation>Nombre d&apos;évents</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="533"/>
-        <location filename="mainwindow.ui" line="843"/>
+        <location filename="mainwindow.ui" line="553"/>
+        <location filename="mainwindow.ui" line="873"/>
         <source>Port diameter</source>
         <translation>Diamètre d&apos;évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="547"/>
-        <location filename="mainwindow.ui" line="597"/>
-        <location filename="mainwindow.ui" line="637"/>
-        <location filename="mainwindow.ui" line="857"/>
-        <location filename="mainwindow.ui" line="897"/>
+        <location filename="mainwindow.ui" line="567"/>
+        <location filename="mainwindow.ui" line="627"/>
+        <location filename="mainwindow.ui" line="667"/>
+        <location filename="mainwindow.ui" line="887"/>
+        <location filename="mainwindow.ui" line="927"/>
         <source>cm</source>
         <translation>cm</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="567"/>
+        <location filename="mainwindow.ui" line="587"/>
         <source>Slot port</source>
         <translation>Laminaire</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="577"/>
+        <location filename="mainwindow.ui" line="604"/>
         <source>x</source>
         <translatorcomment>multiply sign</translatorcomment>
         <translation>x</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="617"/>
-        <location filename="mainwindow.ui" line="877"/>
+        <location filename="mainwindow.ui" line="647"/>
+        <location filename="mainwindow.ui" line="907"/>
         <source>Port length</source>
         <translation>Longueur d&apos;évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="649"/>
+        <location filename="mainwindow.ui" line="679"/>
         <source>Bandpass enclosure</source>
         <translation>Caisson de basse</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="652"/>
+        <location filename="mainwindow.ui" line="682"/>
         <source>4th order filter</source>
         <translation>filtre du quatrième ordre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="655"/>
+        <location filename="mainwindow.ui" line="685"/>
         <source>Enclosure for subwoofer, mostly used in 2:1, 5:1 and 7:1 systems.</source>
         <translation>Enceinte pour subwoofer, souvent utilisée pour les systèmes 2:1, 5:1 et 7:1.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="681"/>
+        <location filename="mainwindow.ui" line="711"/>
         <source>Sealed enclosure volume</source>
         <translation>Volume de l&apos;enceinte close</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="738"/>
+        <location filename="mainwindow.ui" line="768"/>
         <source>Ported enclosure volume</source>
         <translation>Volume de l&apos;enceinte à évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="775"/>
+        <location filename="mainwindow.ui" line="805"/>
         <source>Ported enclosure filter resonance</source>
         <translation>Résonnance de l&apos;enceinte à évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="922"/>
+        <location filename="mainwindow.ui" line="952"/>
         <source>Project</source>
         <translation>Projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="934"/>
+        <location filename="mainwindow.ui" line="964"/>
         <source>Edit</source>
         <translation>Éditer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="938"/>
+        <location filename="mainwindow.ui" line="968"/>
         <source>Ported alignments</source>
         <translation>Alignements avec évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="952"/>
+        <location filename="mainwindow.ui" line="985"/>
         <source>About</source>
         <translation>À propos</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="958"/>
+        <location filename="mainwindow.ui" line="991"/>
         <source>Speaker</source>
         <translation>Haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="995"/>
+        <location filename="mainwindow.ui" line="1000"/>
+        <source>Exports</source>
+        <translation>Exports</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1039"/>
         <source>Ctrl+I</source>
         <translation>Ctrl+I</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1000"/>
+        <location filename="mainwindow.ui" line="1044"/>
         <source>Save</source>
         <translation>Enregistrer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1006"/>
+        <location filename="mainwindow.ui" line="1050"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1017"/>
+        <location filename="mainwindow.ui" line="1061"/>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1022"/>
+        <location filename="mainwindow.ui" line="1066"/>
         <source>Print</source>
         <translation>Imprimer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1025"/>
+        <location filename="mainwindow.ui" line="1069"/>
         <source>Print the current project</source>
         <translation>Imprime le projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1028"/>
+        <location filename="mainwindow.ui" line="1072"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1033"/>
+        <location filename="mainwindow.ui" line="1077"/>
         <source>Quit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1036"/>
+        <location filename="mainwindow.ui" line="1080"/>
         <source>Quit the application</source>
         <translation>Quitte l&apos;application</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1039"/>
+        <location filename="mainwindow.ui" line="1083"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1044"/>
-        <location filename="mainwindow.cpp" line="584"/>
+        <location filename="mainwindow.ui" line="1088"/>
+        <location filename="mainwindow.cpp" line="890"/>
         <source>About QSpeakers</source>
         <translation>À propos de QSpeakers</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1047"/>
+        <location filename="mainwindow.ui" line="1091"/>
         <source>Ctrl+A</source>
         <translation>Ctrl+A</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1052"/>
+        <location filename="mainwindow.ui" line="1096"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1055"/>
+        <location filename="mainwindow.ui" line="1099"/>
         <source>New speaker parameters</source>
         <translation>Nouveau haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1058"/>
+        <location filename="mainwindow.ui" line="1102"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1063"/>
+        <location filename="mainwindow.ui" line="1107"/>
         <source>Search</source>
         <translation>Rechercher</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1066"/>
+        <location filename="mainwindow.ui" line="1110"/>
         <source>Search a speaker</source>
         <translation>Recherche un haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1071"/>
+        <location filename="mainwindow.ui" line="1115"/>
         <source>Optimize</source>
         <translation>Optimiser</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1074"/>
+        <location filename="mainwindow.ui" line="1118"/>
         <source>Optimize frequency response</source>
         <translation>Optimise la réponse en fréquence</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1077"/>
+        <location filename="mainwindow.ui" line="1121"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1082"/>
+        <location filename="mainwindow.ui" line="1126"/>
         <source>Modify</source>
         <translation>Modifier</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1085"/>
+        <location filename="mainwindow.ui" line="1129"/>
         <source>Modify the current speaker</source>
         <translation>Modifie le haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1088"/>
+        <location filename="mainwindow.ui" line="1132"/>
         <source>Ctrl+M</source>
         <translation>Ctrl+M</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1093"/>
+        <location filename="mainwindow.ui" line="1137"/>
         <source>Remove</source>
         <translation>Retirer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1096"/>
+        <location filename="mainwindow.ui" line="1140"/>
         <source>Remove the current speaker</source>
         <translation>Retire le haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1101"/>
+        <location filename="mainwindow.ui" line="1145"/>
         <source>Bessel</source>
         <translation>Bessel</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1104"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Linear phase and fast transient response alignment.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Alignement à phase linéaire et réponse transitoire courte.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <location filename="mainwindow.ui" line="1148"/>
+        <source>Linear phase and fast transient response alignment</source>
+        <translation>Alignement à phase linéaire et réponse en transitoire rapide</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1133"/>
+        <location filename="mainwindow.ui" line="1156"/>
+        <source>Extended bass response with minimum ripple</source>
+        <translation>Réponse étendue en grave avec un minimum d&apos;oscillation</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1164"/>
+        <source>Boom box butterworth 4th order alignment</source>
+        <translation>Alignement Butterworth du 4è ordre «Boom box»</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1172"/>
+        <source>Super boom box butterworth 4th order alignment</source>
+        <translation>Alignement Butterworth du 4è ordre «Super boom box»</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1194"/>
+        <source>Undo</source>
+        <translation>Défaire</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1197"/>
+        <source>Undo action</source>
+        <translation>Défaire</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1200"/>
+        <source>Ctrl+U</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1209"/>
+        <source>Redo</source>
+        <translation>Refaire</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1212"/>
+        <source>Redo action</source>
+        <translation>Refaire</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1215"/>
+        <source>Ctrl+R</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1220"/>
+        <source>3D OpenScad</source>
+        <translation>OpenScad 3D</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1225"/>
+        <source>2D OpenScad</source>
+        <translation>OpenScad 2D</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1230"/>
+        <source>Curve Plot</source>
+        <translation>Courbe</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1177"/>
         <source>Zbinden M4</source>
         <translation>M4 Zbinden</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1141"/>
-        <source>Bandpass alignement</source>
+        <location filename="mainwindow.ui" line="1180"/>
+        <source>Moderate alignment (infinite baffle)</source>
+        <translation>Alignement modéré (sur baffle infini)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1185"/>
+        <source>Bandpass alignment</source>
         <translation>Alignement caisson de basse</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1128"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Super boom box butterworth 4th order alignment.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Alignement butterworth du 4ème ordre pour un super boom box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="1136"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Moderate alignment (infinite baffle).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <oldsource>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Moderate alignment for indoor (infinite baffle) application.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Alignment modéré (baffle infini).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="1109"/>
+        <location filename="mainwindow.ui" line="1153"/>
         <source>Legendre</source>
         <translation>Legendre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="989"/>
+        <location filename="mainwindow.ui" line="1033"/>
         <source>Open...</source>
         <translation>Ouvrir...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="992"/>
+        <location filename="mainwindow.ui" line="219"/>
+        <source>Dia</source>
+        <translation>Dia</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="259"/>
+        <source>Z</source>
+        <translation>Z</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1036"/>
         <source>Open a speaker project</source>
         <translation>Ouvre un projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1003"/>
+        <location filename="mainwindow.ui" line="1047"/>
         <source>Save the current project</source>
         <translation>Enregistre le projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1011"/>
+        <location filename="mainwindow.ui" line="1055"/>
         <source>Save copy...</source>
         <translation>Enregistrer une copie...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1014"/>
+        <location filename="mainwindow.ui" line="1058"/>
         <source>Save the current project in a copy</source>
         <translation>Enregistre une copie du projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1112"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Extended bass response with minimum ripple.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Réponse étendue dans le grave avec un minimum d&apos;oscillation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="1117"/>
+        <location filename="mainwindow.ui" line="1161"/>
         <source>Hoge BB4</source>
         <translation>BB4 Hoge</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1120"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Boom box butterworth 4th order alignment.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <oldsource>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Boom box butterworht 4th order alignment.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Alignement butterworth du 4ème ordre pour une boom box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="1125"/>
+        <location filename="mainwindow.ui" line="1169"/>
         <source>Bullock SBB4</source>
         <translation>SBB4 Bullock</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="45"/>
+        <location filename="mainwindow.cpp" line="51"/>
         <source>Sealed volume frequency response</source>
         <translation>Réponse fréquentielle de l&apos;enceinte close</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="50"/>
+        <location filename="mainwindow.cpp" line="56"/>
         <source>Ported volume frequency response</source>
         <translation>Réponse fréquentielle de l&apos;enceinte à évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="55"/>
+        <location filename="mainwindow.cpp" line="61"/>
         <source>Bandpass volumes frequency response</source>
         <translation>Réponse fréquentielle du caisson de basse</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="180"/>
+        <location filename="mainwindow.cpp" line="140"/>
         <source>Export File</source>
         <translation>Exporter le fichier</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="180"/>
+        <location filename="mainwindow.cpp" line="140"/>
         <source>/untitled.qsp</source>
         <translation>/sans nom.qsp</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="180"/>
-        <location filename="mainwindow.cpp" line="198"/>
+        <location filename="mainwindow.cpp" line="140"/>
+        <location filename="mainwindow.cpp" line="158"/>
         <source>QSpeakers project (*.qsp)</source>
         <translation>Projet QSpeakers (*.qsp)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="190"/>
-        <location filename="mainwindow.cpp" line="235"/>
+        <location filename="mainwindow.cpp" line="150"/>
+        <location filename="mainwindow.cpp" line="202"/>
         <source>Project not saved</source>
         <translation>Projet non enregistré</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="191"/>
+        <location filename="mainwindow.cpp" line="151"/>
         <source>The current project has not been saved. Continue anyway?</source>
         <translation>Le.projet actuel n&apos;a pas été enregistré. Continuer malgré tout ?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="198"/>
+        <location filename="mainwindow.cpp" line="158"/>
         <source>Import File</source>
         <translation>Importer un fichier</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="236"/>
+        <location filename="mainwindow.cpp" line="203"/>
         <source>The current project has not been saved. Exit anyway?</source>
         <translation>Le projet actuel n&apos;a pas été enregistré. Quitter malgré tout ?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="436"/>
+        <location filename="mainwindow.cpp" line="425"/>
+        <source>Export for Gnuplot</source>
+        <translation>Exporter pour Gnuplot</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="425"/>
+        <source>Gnuplot data (*.dat)</source>
+        <translation>Données Gnuplot (*.dat)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="434"/>
+        <source>Export for 3D OpenSCAD</source>
+        <translation>Export 3D pour OpenSCAD</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="434"/>
+        <source>OpenSCAD script (*.scad)</source>
+        <translation>Script OpenSCAD (*.scad)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="709"/>
         <source>Removal confirmation</source>
         <translation>Confirmation de la suppression</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="437"/>
+        <location filename="mainwindow.cpp" line="710"/>
         <source>Do you really want to remove this loudspeaker from the database?</source>
         <translation>Voulez-vous vraiment retirer ce haut-parleur de la base de données ?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="585"/>
+        <location filename="mainwindow.cpp" line="891"/>
         <source>QSpeakers version </source>
         <translation>QSpeakers version </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="711"/>
-        <location filename="mainwindow.cpp" line="736"/>
+        <location filename="mainwindow.cpp" line="1027"/>
+        <location filename="mainwindow.cpp" line="1084"/>
         <source>Unsaved speaker</source>
         <translation>Haut-parleur non enregistré</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="712"/>
-        <location filename="mainwindow.cpp" line="737"/>
+        <location filename="mainwindow.cpp" line="1028"/>
+        <location filename="mainwindow.cpp" line="1085"/>
         <source>This speaker is not present in the database. Would you like to insert it before to continue?</source>
         <translation>Ce haut-parleur n&apos;est pas présent dans la base de données. Voulez-vous l&apos;insérer avant de continuer ?</translation>
     </message>
@@ -533,12 +611,12 @@
 <context>
     <name>Plot</name>
     <message>
-        <location filename="plot.cpp" line="199"/>
+        <location filename="plot.cpp" line="204"/>
         <source>Frequency [Hz]</source>
         <translation>Fréquence [Hz]</translation>
     </message>
     <message>
-        <location filename="plot.cpp" line="207"/>
+        <location filename="plot.cpp" line="212"/>
         <source>Sound pressure [dB]</source>
         <translation>Pression sonore [dB]</translation>
     </message>
@@ -564,44 +642,84 @@
     </message>
     <message>
         <location filename="bandpassbox.cpp" line="125"/>
-        <location filename="portedbox.cpp" line="174"/>
+        <location filename="portedbox.cpp" line="197"/>
         <source>Port Diam. %1 cm</source>
         <translation>Diam. Évent %1 cm</translation>
     </message>
     <message>
         <location filename="bandpassbox.cpp" line="126"/>
-        <location filename="portedbox.cpp" line="176"/>
+        <location filename="portedbox.cpp" line="201"/>
         <source>Port Len. %1 cm</source>
         <translation>Long. Évent %1 cm</translation>
     </message>
     <message>
         <location filename="bandpassbox.cpp" line="127"/>
-        <location filename="portedbox.cpp" line="177"/>
+        <location filename="portedbox.cpp" line="202"/>
         <source>Port Num. %1</source>
         <translation>Nombre Évent %1</translation>
     </message>
     <message>
         <location filename="bandpassbox.cpp" line="128"/>
-        <location filename="portedbox.cpp" line="178"/>
+        <location filename="portedbox.cpp" line="203"/>
         <source>Fb %1 Hz</source>
         <translation>Fb %1 Hz</translation>
     </message>
     <message>
-        <location filename="portedbox.cpp" line="173"/>
+        <location filename="portedbox.cpp" line="195"/>
         <location filename="sealedbox.cpp" line="51"/>
         <source>Vol. %1 L</source>
         <translation>Vol. %1 L</translation>
     </message>
     <message>
-        <location filename="portedbox.cpp" line="175"/>
-        <source>[Slot %1x%2 cm]</source>
-        <translation>[Laminaire %1x%2 cm]</translation>
+        <location filename="portedbox.cpp" line="199"/>
+        <source>Slot port %1 x %2 cm</source>
+        <translation>Évent laminaire %1 x %2 cm</translation>
     </message>
     <message>
         <location filename="system.cpp" line="83"/>
         <source>Driver(s) number: </source>
         <translation>Nombre de haut-parleur(s) : </translation>
     </message>
+    <message>
+        <location filename="optimizer.cpp" line="46"/>
+        <source>optimizing sealed box</source>
+        <translation>optimisation de l&apos;enceinte close</translation>
+    </message>
+    <message>
+        <location filename="optimizer.cpp" line="54"/>
+        <source>applying &apos;max flat&apos; alignment</source>
+        <translation>application de l&apos;alignement &apos;max flat&apos;</translation>
+    </message>
+    <message>
+        <location filename="optimizer.cpp" line="67"/>
+        <source>applying Bessel alignment</source>
+        <translation>application de l&apos;alignement Bessel</translation>
+    </message>
+    <message>
+        <location filename="optimizer.cpp" line="75"/>
+        <source>applying Bullock alignment</source>
+        <translation>application de l&apos;alignement Bullock</translation>
+    </message>
+    <message>
+        <location filename="optimizer.cpp" line="82"/>
+        <source>applying Keele &amp; Hoge alignment</source>
+        <translation>application de l&apos;alignement Keele &amp; Hoge</translation>
+    </message>
+    <message>
+        <location filename="optimizer.cpp" line="89"/>
+        <source>applying Legendre alignment</source>
+        <translation>application de l&apos;alignement Legendre</translation>
+    </message>
+    <message>
+        <location filename="optimizer.cpp" line="97"/>
+        <source>applying Zbinden alignment</source>
+        <translation>application de l&apos;alignement Zbinden</translation>
+    </message>
+    <message>
+        <location filename="optimizer.cpp" line="133"/>
+        <source>applying bandpass box alignment</source>
+        <translation>application de l&apos;alignement de l&apos;enceinte passe-bande</translation>
+    </message>
 </context>
 <context>
     <name>SearchDialog</name>
@@ -616,7 +734,7 @@
         <translation>est entre</translation>
     </message>
     <message>
-        <location filename="searchdialog.ui" line="49"/>
+        <location filename="searchdialog.ui" line="53"/>
         <source>and</source>
         <translation>et</translation>
     </message>
@@ -649,29 +767,82 @@
         <translation>Fs (Hz)</translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="57"/>
+        <location filename="speakerdialog.ui" line="67"/>
         <source>Qts</source>
         <translation>Qts</translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="64"/>
+        <location filename="speakerdialog.ui" line="81"/>
         <source>Vas (L)</source>
         <translation>Vas (L)</translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="71"/>
+        <location filename="speakerdialog.ui" line="98"/>
+        <source>Dia (m)</source>
+        <translation>Dia (m)</translation>
+    </message>
+    <message>
+        <location filename="speakerdialog.ui" line="115"/>
+        <source>Z (Ohm)</source>
+        <translation>Z (Ohm)</translation>
+    </message>
+    <message>
+        <location filename="speakerdialog.ui" line="129"/>
         <source>Sd (m²)</source>
         <translation>Sd (m²)</translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="108"/>
+        <location filename="speakerdialog.ui" line="143"/>
         <source>Re (Ohm)</source>
         <translation>Re (Ohm)</translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="118"/>
+        <location filename="speakerdialog.ui" line="157"/>
+        <source>Le (mH)</source>
+        <translation>Le (mH)</translation>
+    </message>
+    <message>
+        <location filename="speakerdialog.ui" line="171"/>
         <source>Xmax (mm)</source>
         <translation>Xmax (mm)</translation>
     </message>
+    <message>
+        <location filename="speakerdialog.ui" line="185"/>
+        <source>Qms</source>
+        <translation>Qms</translation>
+    </message>
+    <message>
+        <location filename="speakerdialog.ui" line="199"/>
+        <source>Qes</source>
+        <translation>Qes</translation>
+    </message>
+    <message>
+        <location filename="speakerdialog.ui" line="213"/>
+        <source>Spl (dB)</source>
+        <translation>Spl (dB)</translation>
+    </message>
+    <message>
+        <location filename="speakerdialog.ui" line="230"/>
+        <source>Pe (W)</source>
+        <translation>Pe (W)</translation>
+    </message>
+    <message>
+        <location filename="speakerdialog.ui" line="247"/>
+        <source>BL (Tm)</source>
+        <translation>BL (Tm)</translation>
+    </message>
+    <message>
+        <location filename="speakerdialog.ui" line="261"/>
+        <source>Voice Coil</source>
+        <translation>Nb de voix</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <location filename="main.cpp" line="37"/>
+        <source>Project file to work on.</source>
+        <translation>Fichier du projet sur lequel travailler.</translation>
+    </message>
 </context>
 </TS>
